@@ -30,7 +30,7 @@ def get_batch(
     GetBatch(
         batch_id,
         output_filename,
-        Credentials(email, password, api_key),
-        Optionals(host),
+        Credentials(email=email, password=password, api_key=api_key),
+        Optionals(host=host),
         no_progress,
     ).run()
