@@ -4,8 +4,8 @@ import backoff
 # pylint: disable=wrong-import-order
 from gencove.client import APIClientError, APIClientTimeout  # noqa: I100
 from gencove.command.base import Command
+from gencove.models import Project
 
-from .constants import PipelineCapabilities, Project
 from .utils import get_line
 
 
@@ -36,10 +36,7 @@ class List(Command):
                     self.echo_data(get_line(project))
         except APIClientError as err:
             if err.status_code == 404:
-                self.echo_error(
-                    "You do not have permission required "
-                    "to access the project list."
-                )
+                self.echo_error("No projects found.")
             raise
 
     def get_paginated_projects(self):
@@ -53,8 +50,9 @@ class List(Command):
         while more:
             self.echo_debug("Get projects page")
             resp = self.get_projects(next_link)
-            yield [Project(**result) for result in resp["results"]]
-            next_link = resp["meta"]["next"]
+
+            yield resp.results
+            next_link = resp.meta.next
             more = next_link is not None
 
     @backoff.on_exception(
@@ -75,8 +73,7 @@ class List(Command):
     )
     def get_pipeline_capabilities(self, pipeline_id):
         """Get pipeline capabilities."""
-        resp = self.api_client.get_pipeline_capabilities(pipeline_id)
-        return PipelineCapabilities(**resp)
+        return self.api_client.get_pipeline_capabilities(pipeline_id)
 
     def augment_projects_with_pipeline_capabilities(self, projects):
         """Fetch pipeline capabilities and append it to the project.
@@ -92,6 +89,6 @@ class List(Command):
             pipeline_capabilities = self.get_pipeline_capabilities(
                 project.pipeline_capabilities
             )
-            yield project._replace(
-                pipeline_capabilities=pipeline_capabilities
-            )
+            project_dict = dict(project)
+            project_dict["pipeline_capabilities"] = pipeline_capabilities
+            yield Project(**project_dict)
