@@ -12,8 +12,8 @@ def get_line(merged_vcf):
     """
     return "\t".join(
         [
-            merged_vcf["id"],
-            merged_vcf["last_status"]["created"],
-            merged_vcf["last_status"]["status"],
+            str(merged_vcf.id),
+            merged_vcf.last_status.created.isoformat(),
+            merged_vcf.last_status.status,
         ]
     )
