@@ -6,6 +6,7 @@ from click.testing import CliRunner
 
 from gencove.client import APIClient, APIClientError, APIClientTimeout
 from gencove.command.projects.cli import get_merged_vcf
+from gencove.models import Project
 
 
 def test_get_merged_vcf__bad_project_id(mocker):
@@ -18,6 +19,7 @@ def test_get_merged_vcf__bad_project_id(mocker):
     mocked_get_project = mocker.patch.object(
         APIClient,
         "get_project",
+        return_value=Project(id=str(uuid4())),
     )
 
     res = runner.invoke(
@@ -48,7 +50,7 @@ def test_get_merged_vcf__not_owned_project(mocker):
         APIClient,
         "get_project",
         return_value=mocked_response,
-        side_effect=APIClientError(message="", status_code=404),
+        side_effect=APIClientError(message="", status_code=403),
     )
 
     res = runner.invoke(
@@ -65,7 +67,7 @@ def test_get_merged_vcf__not_owned_project(mocker):
     assert res.exit_code == 1
     mocked_login.assert_called_once()
     mocked_get_project.assert_called_once()
-    assert "you do not have permission required" in res.output
+    assert "You do not have the sufficient permission" in res.output
 
 
 def test_get_merged_vcf__empty(mocker):
@@ -78,13 +80,12 @@ def test_get_merged_vcf__empty(mocker):
     mocked_get_project = mocker.patch.object(
         APIClient,
         "get_project",
-        return_value=dict(
+        return_value=Project(
             id=project_id,
             name="Project Cadmus",
             description="",
             created="2020-06-11T02:14:00.541889Z",
             organization=str(uuid4()),
-            webhook_url="",
             sample_count=3,
             pipeline_capabilites=str(uuid4()),
             files=[],
@@ -124,13 +125,12 @@ def test_get_merged_vcf_custom_filename(mocker):
     mocked_get_project = mocker.patch.object(
         APIClient,
         "get_project",
-        return_value=dict(
+        return_value=Project(
             id=project_id,
             name="Project Cadmus",
             description="",
             created="2020-06-11T02:14:00.541889Z",
             organization=str(uuid4()),
-            webhook_url="",
             sample_count=3,
             pipeline_capabilites=str(uuid4()),
             files=[
@@ -184,13 +184,12 @@ def test_get_merged_vcf__no_progress_success(mocker):
     mocked_get_project = mocker.patch.object(
         APIClient,
         "get_project",
-        return_value=dict(
+        return_value=Project(
             id=project_id,
             name="Project Cadmus",
             description="",
             created="2020-06-11T02:14:00.541889Z",
             organization=str(uuid4()),
-            webhook_url="",
             sample_count=3,
             pipeline_capabilites=str(uuid4()),
             files=[
@@ -285,7 +284,72 @@ def test_get_merged_vcf__success(mocker):
     mocked_get_project = mocker.patch.object(
         APIClient,
         "get_project",
-        return_value=dict(
+        return_value=Project(
+            id=project_id,
+            name="Project Cadmus",
+            description="",
+            created="2020-06-11T02:14:00.541889Z",
+            organization=str(uuid4()),
+            sample_count=3,
+            pipeline_capabilites=str(uuid4()),
+            files=[
+                {
+                    "id": "755ec682-e4a5-414a-a5be-07e0af11cf75",
+                    "s3_path": (
+                        "app-data/output/apps/merge_vcfs/"
+                        "{file_id}/{file_id}.vcf.bgz".format(file_id=file_id)
+                    ),
+                    "size": None,
+                    "download_url": (
+                        "https://bucket.s3.amazonaws.com/output/apps/"
+                        "merge_vcfs/{file_id}/{file_id}.vcf.bgz".format(
+                            file_id=file_id
+                        )
+                    ),
+                    "file_type": "impute-vcf-merged",
+                }
+            ],
+        ),
+    )
+
+    with runner.isolated_filesystem():
+        mocked_download_file = mocker.patch(
+            "gencove.command.projects.get_merged_vcf.main.download.utils."
+            "download_file"
+        )
+        res = runner.invoke(
+            get_merged_vcf,
+            [
+                project_id,
+                "--email",
+                "foo@bar.com",
+                "--password",
+                "123",
+            ],
+        )
+    assert res.exit_code == 0
+    mocked_login.assert_called_once()
+    mocked_get_project.assert_called_once()
+    mocked_download_file.assert_called_once_with(
+        "{}.vcf.bgz".format(file_id),
+        "https://bucket.s3.amazonaws.com/output/apps/"
+        "merge_vcfs/{file_id}/{file_id}.vcf.bgz".format(file_id=file_id),
+        no_progress=False,
+    )
+
+
+def test_get_merged_vcf__success__project_with_legacy_webhhok_url(mocker):
+    """Test project download merged VCF success."""
+    project_id = str(uuid4())
+    file_id = str(uuid4())
+
+    runner = CliRunner()
+
+    mocked_login = mocker.patch.object(APIClient, "login", return_value=None)
+    mocked_get_project = mocker.patch.object(
+        APIClient,
+        "get_project",
+        return_value=Project(
             id=project_id,
             name="Project Cadmus",
             description="",
