@@ -9,6 +9,7 @@ from click.testing import CliRunner
 
 from gencove.client import APIClient, APIClientError, APIClientTimeout
 from gencove.command.projects.cli import status_merged_vcf
+from gencove.models import ProjectMergeVCFs
 
 
 def test_status_merged_vcf__bad_project_id(mocker):
@@ -72,8 +73,7 @@ def test_status_merged_vcf__empty(mocker):
     mocked_login.assert_called_once()
     mocked_retrieve_merged_vcf.assert_called_once()
     message = (
-        "Project {} does not exist or you do not have "
-        "permission required to access it or there are no "
+        "Project {} does not exist or there are no "
         "running jobs associated with it.".format(project_id)
     )
     assert message in res.output
@@ -138,7 +138,9 @@ def test_status_merged_vcf__success_but_job_failed(mocker):
 
     mocked_login = mocker.patch.object(APIClient, "login", return_value=None)
     mocked_retrieve_merged_vcf = mocker.patch.object(
-        APIClient, "retrieve_merged_vcf", return_value=mocked_response
+        APIClient,
+        "retrieve_merged_vcf",
+        return_value=ProjectMergeVCFs(**mocked_response),
     )
 
     res = runner.invoke(
@@ -192,13 +194,13 @@ def test_status_merged_vcf__success(mocker):
     project_id = str(uuid4())
     mocked_response = {
         "id": project_id,
-        "created": "2020-09-14T08:59:00.480Z",
+        "created": "2020-09-14T08:59:00.480+00:00",
         "user": str(uuid4()),
         "last_status": {
             "id": str(uuid4()),
             "status": "success",
             "note": "",
-            "created": "2020-07-28T12:46:22.719862Z",
+            "created": "2020-07-28T12:46:22.719862+00:00",
         },
         "up_to_date": False,
     }
@@ -207,7 +209,9 @@ def test_status_merged_vcf__success(mocker):
 
     mocked_login = mocker.patch.object(APIClient, "login", return_value=None)
     mocked_retrieve_merged_vcf = mocker.patch.object(
-        APIClient, "retrieve_merged_vcf", return_value=mocked_response
+        APIClient,
+        "retrieve_merged_vcf",
+        return_value=ProjectMergeVCFs(**mocked_response),
     )
 
     res = runner.invoke(
